==> crm-commom-vo-1.0.0.release.jar: com/biz/crm/nebular/tpm/feebudget/resp/TpmFeeBudgetDetailsRespVo.java <==
package com.biz.crm.nebular.tpm.feebudget.resp;
import com.biz.crm.nebular.mdm.CrmExtVo;
import io.swagger.annotations.ApiModel;
import lombok.Data;
import io.swagger.annotations.ApiModelProperty;
import com.fasterxml.jackson.annotation.JsonFormat;
import java.math.BigDecimal;
import java.util.Date;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import javax.persistence.Entity;
import javax.persistence.Table;

/**
 * 费用预算明细 返回vo
 *
 * @author huanglong
 * @date 2020-09-16 10:42:32
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "费用预算明细 ")
@SaturnEntity(name = "TpmFeeBudgetDetailsRespVo", description = "费用预算明细 ")
public class TpmFeeBudgetDetailsRespVo extends CrmExtVo {
    @ApiModelProperty("费用预算编码")
    @SaturnColumn(description = "费用预算编码")
    private String feeBudgetCode;

    @ApiModelProperty("业务单据编码")
    @SaturnColumn(description = "业务单据编码")
    private String businessCode;

    @ApiModelProperty("业务单据名称")
    @SaturnColumn(description = "业务单据名称")
    private String businessName;

    @ApiModelProperty("业务单据明细编码")
    @SaturnColumn(description = "业务单据明细编码")
    private String businessLineCode;

    @ApiModelProperty("业务备注")
    @SaturnColumn(description = "业务备注")
    private String businessRemarks;

    @ApiModelProperty("费用预算明细类型(字典)")
    @SaturnColumn(description = "费用预算明细类型(字典)")
    private String feeBudgetDetailType;

    @ApiModelProperty("费用预算明细类型名称")
    @SaturnColumn(description = "费用预算明细类型名称")
    private String feeBudgetDetailTypeName;

    @ApiModelProperty("年份(明细产生的年份)")
    @SaturnColumn(description = "年份(明细产生的年份)")
    private String year;

    @ApiModelProperty("月份(明细产生的月份)")
    @SaturnColumn(description = "月份(明细产生的月份)")
    private String month;

    @ApiModelProperty("预算科目编码")
    @SaturnColumn(description = "预算科目编码")
    private String budgetSubjectsCode;

    @ApiModelProperty("预算科目名称")
    @SaturnColumn(description = "预算科目名称")
    private String budgetSubjectsName;

    @ApiModelProperty("客户编码")
    @SaturnColumn(description = "客户编码")
    private String customerCode;

    @ApiModelProperty("客户名称")
    @SaturnColumn(description = "客户名称")
    private String customerName;

    @ApiModelProperty("客户所属组织编码")
    @SaturnColumn(description = "客户所属组织编码")
    private String customerOrgCode;

    @ApiModelProperty("客户所属组织名称")
    @SaturnColumn(description = "客户所属组织名称")
    private String customerOrgName;

    @ApiModelProperty("产品编码")
    @SaturnColumn(description = "产品编码")
    private String productCode;

    @ApiModelProperty("产品名称")
    @SaturnColumn(description = "产品名称")
    private String productName;

    @ApiModelProperty("渠道编码")
    @SaturnColumn(description = "渠道编码")
    private String channel;

    @ApiModelProperty("渠道名称")
    @SaturnColumn(description = "渠道名称")
    private String channelName;

    @ApiModelProperty("企业组织编码")
    @SaturnColumn(description = "企业组织编码")
    private String orgCode;

    @ApiModelProperty("企业组织名称")
    @SaturnColumn(description = "企业组织名称")
    private String orgName;

    @ApiModelProperty("期初金额")
    @SaturnColumn(description = "期初金额")
    private BigDecimal initAmount;

    @ApiModelProperty("金额;当前操作金额")
    @SaturnColumn(description = "金额;当前操作金额")
    private BigDecimal feeAmount;

    @ApiModelProperty("操作前余额;当前余额")
    @SaturnColumn(description = "操作前余额;当前余额")
    private BigDecimal beforAmount;

    @ApiModelProperty("操作后余额")
    @SaturnColumn(description = "操作后余额")
    private BigDecimal afterAmount;

}

==> crm-commom-vo-1.0.6.release.jar: com/biz/crm/nebular/tpm/feebudget/resp/TpmFeeBudgetDetailsRespVo.java <==
package com.biz.crm.nebular.tpm.feebudget.resp;
import com.biz.crm.nebular.mdm.CrmExtVo;
import io.swagger.annotations.ApiModel;
import lombok.Data;
import io.swagger.annotations.ApiModelProperty;
import com.fasterxml.jackson.annotation.JsonFormat;
import java.math.BigDecimal;
import java.util.Date;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import javax.persistence.Entity;
import javax.persistence.Table;

/**
 * 费用预算明细 返回vo
 *
 * @author huanglong
 * @date 2020-09-16 10:42:32
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "费用预算明细 ")
@SaturnEntity(name = "TpmFeeBudgetDetailsRespVo", description = "费用预算明细 ")
public class TpmFeeBudgetDetailsRespVo extends CrmExtVo {
    @ApiModelProperty("费用预算编码")
    @SaturnColumn(description = "费用预算编码")
    private String feeBudgetCode;

    @ApiModelProperty("费用预算类型(字典)")
    @SaturnColumn(description = "费用预算类型(字典)")
    private String feeBudgetType;

    @ApiModelProperty("组织类型")
    @SaturnColumn(description = "组织类型")
    private String orgType;

    @ApiModelProperty("预算扣减顺序")
    @SaturnColumn(description = "预算扣减顺序")
    private Integer reduceOrder;

    @ApiModelProperty("预算扣减比例")
    @SaturnColumn(description = "预算扣减比例")
    private BigDecimal reduceRatio;

    @ApiModelProperty("业务单据编码")
    @SaturnColumn(description = "业务单据编码")
    private String businessCode;

    @ApiModelProperty("业务单据名称")
    @SaturnColumn(description = "业务单据名称")
    private String businessName;

    @ApiModelProperty("业务单据明细编码")
    @SaturnColumn(description = "业务单据明细编码")
    private String businessLineCode;

    @ApiModelProperty("业务备注")
    @SaturnColumn(description = "业务备注")
    private String businessRemarks;

    @ApiModelProperty("费用预算明细类型(字典)")
    @SaturnColumn(description = "费用预算明细类型(字典)")
    private String feeBudgetDetailType;

    @ApiModelProperty("费用预算明细类型名称")
    @SaturnColumn(description = "费用预算明细类型名称")
    private String feeBudgetDetailTypeName;

    @ApiModelProperty("年份(明细产生的年份)")
    @SaturnColumn(description = "年份(明细产生的年份)")
    private String year;

    @ApiModelProperty("月份(明细产生的月份)")
    @SaturnColumn(description = "月份(明细产生的月份)")
    private String month;

    @ApiModelProperty("预算科目编码")
    @SaturnColumn(description = "预算科目编码")
    private String budgetSubjectsCode;

    @ApiModelProperty("预算科目名称")
    @SaturnColumn(description = "预算科目名称")
    private String budgetSubjectsName;

    @ApiModelProperty("客户编码")
    @SaturnColumn(description = "客户编码")
    private String customerCode;

    @ApiModelProperty("客户名称")
    @SaturnColumn(description = "客户名称")
    private String customerName;

    @ApiModelProperty("客户所属组织编码")
    @SaturnColumn(description = "客户所属组织编码")
    private String customerOrgCode;

    @ApiModelProperty("客户所属组织名称")
    @SaturnColumn(description = "客户所属组织名称")
    private String customerOrgName;

    @ApiModelProperty("产品编码")
    @SaturnColumn(description = "产品编码")
    private String productCode;

    @ApiModelProperty("产品名称")
    @SaturnColumn(description = "产品名称")
    private String productName;

    @ApiModelProperty("渠道编码")
    @SaturnColumn(description = "渠道编码")
    private String channel;

    @ApiModelProperty("渠道名称")
    @SaturnColumn(description = "渠道名称")
    private String channelName;

    @ApiModelProperty("企业组织编码")
    @SaturnColumn(description = "企业组织编码")
    private String orgCode;

    @ApiModelProperty("企业组织名称")
    @SaturnColumn(description = "企业组织名称")
    private String orgName;

    @ApiModelProperty("期初金额")
    @SaturnColumn(description = "期初金额")
    private BigDecimal initAmount;

    @ApiModelProperty("金额;当前操作金额")
    @SaturnColumn(description = "金额;当前操作金额")
    private BigDecimal feeAmount;

    @ApiModelProperty("操作前余额;当前余额")
    @SaturnColumn(description = "操作前余额;当前余额")
    private BigDecimal beforAmount;

    @ApiModelProperty("操作后余额")
    @SaturnColumn(description = "操作后余额")
    private BigDecimal afterAmount;

}
